<!DOCTYPE TS><TS>
<context>
    <name>GuideGrid</name>
    <message>
        <source>Recording Once</source>
        <translation type="obsolete">Grabar una vez</translation>
    </message>
    <message>
        <source>Timeslot Recording</source>
        <translation type="obsolete">Grabar en esta franja horaria</translation>
    </message>
    <message>
        <source>Channel Recording</source>
        <translation type="obsolete">Grabar en el canal</translation>
    </message>
    <message>
        <source>All Recording</source>
        <translation type="obsolete">Grabar en todas partes</translation>
    </message>
    <message>
        <source>Not Recording</source>
        <translation type="obsolete">No grabar</translation>
    </message>
    <message>
        <source>Weekly Recording</source>
        <translation type="obsolete">Grabación semanal</translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <source>Episode:</source>
        <translation type="obsolete">Episodio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="obsolete">Descripción:</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown anywhere</source>
        <translation>Grabar este programa en cualquier siempre que aparezca</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown on this channel</source>
        <translation>Grabar este programa siempre que aparezca en este canal</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every day</source>
        <translation>Grabar este programa a esta hora cada dia</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every week</source>
        <translation>Grabar este programa a esta hora cada semana</translation>
    </message>
    <message>
        <source>Record only this showing of the program</source>
        <translation>Graba este programa solamente esta vez</translation>
    </message>
    <message>
        <source>Don&apos;t record this program</source>
        <translation>No grabar este programa</translation>
    </message>
    <message>
        <source>To go to the advanced recordings screen, press &apos;i&apos;</source>
        <translation>Para ver las opciones avanzadas de grabación, pulse &apos;i&apos;</translation>
    </message>
    <message>
        <source>To see a list of all up-coming showings of this program, press &apos;5&apos;</source>
        <translation>Para ver cuándo se emite este programa, pulse &apos;5&apos;</translation>
    </message>
</context>
<context>
    <name>ManualBox</name>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Manual Recording</source>
        <translation>Grabación manual</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Programa:</translation>
    </message>
    <message>
        <source>Subtitle:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
</context>
<context>
    <name>ManualSchedule</name>
    <message>
        <source>Manual Recording Scheduler</source>
        <translation>Programación Manual de Grabaciones</translation>
    </message>
    <message>
        <source>Channel:</source>
        <translation>Canal: </translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Fecha: </translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Hora: </translation>
    </message>
    <message>
        <source>hr</source>
        <translation></translation>
    </message>
    <message>
        <source>min</source>
        <translation></translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Duración:</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Programa:</translation>
    </message>
    <message>
        <source>Subtitle:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Save this scheduled recording and exit</source>
        <translation>Confirmar esta programación y salir</translation>
    </message>
    <message>
        <source>Save this scheduled recording and set another</source>
        <translation>Confirmar esta programación y establecer otra</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abandonar</translation>
    </message>
    <message>
        <source>Manual recording</source>
        <translation>Programación Manual</translation>
    </message>
</context>
<context>
    <name>MythContext</name>
    <message>
        <source>Connection to the master backend server timed out.  You probably should modify the Master Server setting in the setup program and set the proper IP address there.</source>
        <translation type="obsolete">Tiempo de espera agotado para conectar con el backend. Probablemente debes de configurar correctamente la dirección IP.</translation>
    </message>
    <message>
        <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
        <translation>No puedo conectar con el servidor backend, ¿está funcionando? ¿La IP establecida en la configuración es la correcta?</translation>
    </message>
    <message>
        <source>The connection to the master backend server has gone away for some reason.. Is it running?</source>
        <translation>Se perdió la conexión con el backend por alguna razón.... ¿está funcionando?</translation>
    </message>
</context>
<context>
    <name>MythWizard</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>&lt; &amp;Back</source>
        <translation>&lt; &amp;Atrás</translation>
    </message>
    <message>
        <source>&amp;Next &gt;</source>
        <translation>&amp;Siguiente&gt;</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Finalizar</translation>
    </message>
</context>
<context>
    <name>NuppelVideoPlayer</name>
    <message>
        <source>SKIP</source>
        <translation type="obsolete">SALTO</translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>% used</source>
        <translation>% ocupado</translation>
    </message>
    <message>
        <source>, %d,%03d MB free</source>
        <translation>, %d,%03d MB libres</translation>
    </message>
    <message>
        <source>All Programs</source>
        <translation>Todas</translation>
    </message>
    <message>
        <source>You have finished watching:</source>
        <translation>Ha acabado de ver:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete:</source>
        <translation>¿Está seguro que quiere borrar?:</translation>
    </message>
    <message>
        <source>Delete this recording? It will be gone forever.</source>
        <translation type="obsolete">¿Borrar esta grabación? Se borrará definitivamente.</translation>
    </message>
    <message>
        <source>It will be gone forever.</source>
        <translation type="obsolete">Será definitivo.</translation>
    </message>
    <message>
        <source>Yes, get rid of it</source>
        <translation>Si, borrarla</translation>
    </message>
    <message>
        <source>No, I might want to watch it again.</source>
        <translation>No. Quiero poder volver a verla.</translation>
    </message>
    <message>
        <source>No, keep it, I changed my mind</source>
        <translation>No, guárdala, he cambiado de idea</translation>
    </message>
    <message>
        <source>Delete this recording?</source>
        <translation>¿Borrar esta grabación?</translation>
    </message>
    <message>
        <source>Allow this program to AutoExpire?</source>
        <translation>¿Permitor que esta grabación autoexpire?</translation>
    </message>
    <message>
        <source>Yes, AutoExpire</source>
        <translation>Si, autoexpira</translation>
    </message>
    <message>
        <source>Are you sure you want to stop:</source>
        <translation>¿Está seguro que quiere parar?:</translation>
    </message>
    <message>
        <source>Yes, stop recording it</source>
        <translation>Si, parar la grabación</translation>
    </message>
    <message>
        <source>No, do not AutoExpire</source>
        <translation>No, no autoexpirar</translation>
    </message>
    <message>
        <source>No, continue recording it</source>
        <translation>No, continuar grabándolo</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Escoja una acción:</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Stop Recording</source>
        <translation>Parar la grabación</translation>
    </message>
    <message>
        <source>Don&apos;t Auto Expire</source>
        <translation>No autoexpirar</translation>
    </message>
    <message>
        <source>Auto Expire</source>
        <translation>Autoexpirar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Yes; allow re-recording</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ProgFinder</name>
    <message>
        <source>No Programs</source>
        <translation>No hay programas</translation>
    </message>
    <message>
        <source>There are no available programs under this search. Please select another search.</source>
        <translation>No hay programas disponibles en esta búsqueda. Realice otra búsqueda.</translation>
    </message>
    <message>
        <source>Recording just this showing</source>
        <translation>Graba el programa solamente esta vez</translation>
    </message>
    <message>
        <source>Recording when shown in this timeslot</source>
        <translation type="obsolete">Grabarlo cuando aparezca a esta hora</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation>Grabarlo cuando aparezca en este canal</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation>Grabarlo siempre que aparezca</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation>No grabar este programa</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation>¡ Error !</translation>
    </message>
    <message>
        <source>       !! No Programs !!</source>
        <translation>¡¡ No hay programas !!</translation>
    </message>
    <message>
        <source>Recording every day when shown in this timeslot</source>
        <translation>Grabar cada dia que se emita a esta hora</translation>
    </message>
    <message>
        <source>Recording every week when shown in this timeslot</source>
        <translation>Grabar semanalmente si se emite a esta hora</translation>
    </message>
</context>
<context>
    <name>ProgLister</name>
    <message>
        <source>Recording just this showing</source>
        <translation type="obsolete">Graba el programa solamente esta vez</translation>
    </message>
    <message>
        <source>Recording every day when shown in this timeslot</source>
        <translation type="obsolete">Graba el programa cada dia en esta franja</translation>
    </message>
    <message>
        <source>Recording every week when shown in this timeslot</source>
        <translation type="obsolete">Graba el programa cada semana en esta franja</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation type="obsolete">Grabarlo cuando aparezca en este canal</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation type="obsolete">Grabarlo siempre que aparezca</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation type="obsolete">No grabar este programa</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">¡ Error !</translation>
    </message>
</context>
<context>
    <name>ProgramRecPriority</name>
    <message>
        <source>Recording just this showing</source>
        <translation type="unfinished">Graba el programa solamente esta vez</translation>
    </message>
    <message>
        <source>Recording every week</source>
        <translation type="unfinished">Grabar cada semana</translation>
    </message>
    <message>
        <source>Recording when shown in this timeslot</source>
        <translation type="unfinished">Grabarlo cuando aparezca a esta hora</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation type="unfinished">Grabarlo cuando aparezca en este canal</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation type="unfinished">Grabarlo siempre que aparezca</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation type="unfinished">No grabar este programa</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="unfinished">¡ Error !</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No</source>
        <translation></translation>
    </message>
    <message>
        <source>Yes, Exit now</source>
        <translation>Si, salir ahora</translation>
    </message>
    <message>
        <source>Yes, Exit and shutdown the computer</source>
        <translation type="obsolete">Si, salir ahora y apagar el equipo</translation>
    </message>
    <message>
        <source>Do you really want to exit MythTV?</source>
        <translation>¿Realmente desea salir de MythTV?</translation>
    </message>
    <message>
        <source>cut point</source>
        <translation>punto de corte</translation>
    </message>
    <message>
        <source>keyframe</source>
        <translation>fotograma</translation>
    </message>
    <message>
        <source>1 frame</source>
        <translation>Un fotograma</translation>
    </message>
    <message>
        <source>0.5 seconds</source>
        <translation>medio segundo</translation>
    </message>
    <message>
        <source>1 second</source>
        <translation>Un segundo</translation>
    </message>
    <message>
        <source>5 seconds</source>
        <translation>5 segundos</translation>
    </message>
    <message>
        <source>20 seconds</source>
        <translation>20 segundos</translation>
    </message>
    <message>
        <source>1 minute</source>
        <translation>Un minuto</translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation>5 minutos</translation>
    </message>
    <message>
        <source>10 minutes</source>
        <translation>10 minutos</translation>
    </message>
    <message>
        <source>error</source>
        <translation>error</translation>
    </message>
    <message>
        <source>You are close to an existing cut point.  Would you like to:</source>
        <translation>Está cerca de un punto de corte. ¿Que quiere Ud. hacer?:</translation>
    </message>
    <message>
        <source>Delete this cut point</source>
        <translation>Borrar este punto de corte</translation>
    </message>
    <message>
        <source>Move this cut point to the current position</source>
        <translation>Mover el punto de corte a esta posición</translation>
    </message>
    <message>
        <source>Flip directions - delete to the </source>
        <translation>Canviar direcciones - borrar hacia la </translation>
    </message>
    <message>
        <source>right</source>
        <translation>derecha</translation>
    </message>
    <message>
        <source>left</source>
        <translation>izquierda</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abandonar</translation>
    </message>
    <message>
        <source>Insert a new cut point?</source>
        <translation>¿Insertar un nuevo punto de corte?</translation>
    </message>
    <message>
        <source>Delete before this frame</source>
        <translation>Borrar antes de este fotograma</translation>
    </message>
    <message>
        <source>Delete after this frame</source>
        <translation>Borrar después de este fotograma</translation>
    </message>
    <message>
        <source>Auto-Skip %1 seconds</source>
        <translation type="obsolete">Salto automático de %1 segs</translation>
    </message>
    <message>
        <source>SKIP</source>
        <translation type="obsolete">SALTO</translation>
    </message>
    <message>
        <source>Found %1 sec. commercial</source>
        <translation>Encontrados %1 segs. de anuncios</translation>
    </message>
    <message>
        <source>At Start of program.</source>
        <translation type="obsolete">AL inicio del programa.</translation>
    </message>
    <message>
        <source>At End, can not Skip.</source>
        <translation>Al final, no puedo saltar.</translation>
    </message>
    <message>
        <source>Start of program.</source>
        <translation>Inicio del programa.</translation>
    </message>
    <message>
        <source>cut</source>
        <translation>cortes</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Parrilla</translation>
    </message>
    <message>
        <source>Do not record this proram</source>
        <translation type="obsolete">No grabar este programa</translation>
    </message>
    <message>
        <source>Record only this showing</source>
        <translation>Graba este programa solamente esta vez</translation>
    </message>
    <message>
        <source>Record in this timeslot every day</source>
        <translation>Grabar este programa a esta hora cada dia</translation>
    </message>
    <message>
        <source>Record at any time on this channel</source>
        <translation>Grabar este programa siempre que aparezca en este canal</translation>
    </message>
    <message>
        <source>Record at any time on any channel</source>
        <translation>Grabar este programa en cualquier siempre que aparezca</translation>
    </message>
    <message>
        <source>Record in this timeslot every week</source>
        <translation>Grabar este programa a esta hora cada semana</translation>
    </message>
    <message>
        <source>Do not record this program</source>
        <translation>No grabar este programa</translation>
    </message>
    <message>
        <source>Record only this showing of the program</source>
        <translation type="obsolete">Graba este programa solamente esta vez</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every day</source>
        <translation type="obsolete">Grabar este programa a esta hora cada dia</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown on this channel</source>
        <translation type="obsolete">Grabar este programa siempre que aparezca en este canal</translation>
    </message>
    <message>
        <source>Record this program whenever it&apos;s shown anywhere</source>
        <translation type="obsolete">Grabar este programa en cualquier siempre que aparezca</translation>
    </message>
    <message>
        <source>Record this program in this timeslot every week</source>
        <translation type="obsolete">Grabar este programa a esta hora cada semana</translation>
    </message>
    <message>
        <source>Profile</source>
        <translation>Perfil</translation>
    </message>
    <message>
        <source>(unspecified)</source>
        <translation>(sin especificar)</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="obsolete">Ránking</translation>
    </message>
    <message>
        <source>Record duplicates</source>
        <translation>Grabar aunque se trate de episodios duplicados</translation>
    </message>
    <message>
        <source>Auto Expire</source>
        <translation>Permitir que las grabaciones autoexpiren</translation>
    </message>
    <message>
        <source>Maximum number of episodes to keep (set to 0 for ALL)</source>
        <translation>Màximo de episodios a mantener (0 para todos)</translation>
    </message>
    <message>
        <source>Record new episodes and delete oldest once maximum count is reached</source>
        <translation>Grabar nuevos episodios y borrar el más antiguo cuando se alcance el máximo</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind  --  %.2f%% full</source>
        <translation>%02d:%02d:%02d atrás -- %.2f%% lleno</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind</source>
        <translation>%02d:%02d:%02d atrás</translation>
    </message>
    <message>
        <source>%02d:%02d behind  --  %.2f%% full</source>
        <translation>%02d:%02d atrás -- %.2f%% lleno</translation>
    </message>
    <message>
        <source>%02d:%02d behind</source>
        <translation>%02d:%02d atrás</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d of %02d:%02d:%02d</source>
        <translation>%02d:%02d:%02d de %02d:%02d:%02d</translation>
    </message>
    <message>
        <source>%02d:%02d of %02d:%02d</source>
        <translation>%02d:%02d de %02d:%02d</translation>
    </message>
    <message>
        <source>Skip %1 seconds</source>
        <translation>Salta %1 segundos</translation>
    </message>
    <message>
        <source>Not Currently Suppressed</source>
        <translation type="obsolete">Sin suprimir</translation>
    </message>
    <message>
        <source>Not Recording</source>
        <translation>No grabar</translation>
    </message>
    <message>
        <source>Recording Once</source>
        <translation type="obsolete">Grabar una vez</translation>
    </message>
    <message>
        <source>Timeslot Recording</source>
        <translation type="obsolete">Grabar en esta franja horaria</translation>
    </message>
    <message>
        <source>Weekslot Recording</source>
        <translation type="obsolete">Grabar semanalmente</translation>
    </message>
    <message>
        <source>Channel Recording</source>
        <translation>Grabar en el canal</translation>
    </message>
    <message>
        <source>All Recording</source>
        <translation>Grabar en todas partes</translation>
    </message>
    <message>
        <source>Air Date:</source>
        <translation>Fecha de emisión:</translation>
    </message>
    <message>
        <source>Record Schedule:</source>
        <translation>Grabación programada:</translation>
    </message>
    <message>
        <source>Episode:</source>
        <translation>Episodio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Pre-scaling theme images</source>
        <translation>Predimensionando imágenes</translation>
    </message>
    <message>
        <source>Audio output device</source>
        <translation>Dispositivo de salida de audio</translation>
    </message>
    <message>
        <source>Use internal volume controls</source>
        <translation>Usar controles internos de volumen</translation>
    </message>
    <message>
        <source>MythTV can control the PCM and master mixer volume.  If you prefer to use an external mixer program, uncheck this box.</source>
        <translation>MythTV puede controlar los mezcladores de sonido. Si prefiere usar mezcladores externos, desactive esta opción.</translation>
    </message>
    <message>
        <source>Mixer Device</source>
        <translation>Dispositivo de mezcla</translation>
    </message>
    <message>
        <source>Changing the volume adjusts the selected mixer.</source>
        <translation>Los cambios en el volumen ajustan el mezclador selecionado.</translation>
    </message>
    <message>
        <source>Master Mixer Volume</source>
        <translation>Volumen del sonido original</translation>
    </message>
    <message>
        <source>Initial volume for the Master Mixer.  This affects all sound created by the soundcard.  Note: Do not set this too low.</source>
        <translation>Volumen inicial del mezclador. Esto afecta a todo el sonido generado desde la tarjeta de sonido. Nota: No ponerlo demasiado bajo.</translation>
    </message>
    <message>
        <source>PCM Mixer Volume</source>
        <translation>Volumen del mezclador PCM</translation>
    </message>
    <message>
        <source>Initial volume for PCM output.  Use of the volume keys in MythTV will adjust this parameter.</source>
        <translation>Volumen inicial para la salida PCM. Al usar el volumen en MythTV este parámetro se ajustará.</translation>
    </message>
    <message>
        <source>Deinterlace playback</source>
        <translation>Desinetrlinear la reproducción</translation>
    </message>
    <message>
        <source>Make the video look normal on a progressive display (i.e. monitor).  Deinterlace requires that your CPU supports SSE instructions.  Enabling this without proper CPU support will cause the program to segfault. See the HOWTO document for more information.</source>
        <translation>Hacer que el vídeo se vea normalmente en una pantalla progresiva (p.ej.: un monitor). El desinterlineado requiere un procesador que soporte instrucciones SSE. Activar esto sin un procesador adecuado provocará fallos. Lea la documentación para más información.</translation>
    </message>
    <message>
        <source>Extra audio buffering</source>
        <translation>Búffers extras para el audio</translation>
    </message>
    <message>
        <source>This attempts to keep extra audio data in the internal buffers.  Try setting this if you&apos;re getting crackly audio. (Not used for software encoded video.)</source>
        <translation>Esto intenta reservar buffers de audio adicionales. Pruebe de activar esta opción si esta obteniendo un sonido defectuoso. (No se usa en la compresión de vídeo por software.)</translation>
    </message>
    <message>
        <source>Jump amount (in minutes)</source>
        <translation>Salto (en minutos)</translation>
    </message>
    <message>
        <source>How many minutes to jump forward or backward when the jump keys are pressed.</source>
        <translation>Define el número de minutos a saltar atras o adelante cuando se pulsan las teclas de salto.</translation>
    </message>
    <message>
        <source>Fast forward amount (in seconds)</source>
        <translation>Avance rápido (en segundos)</translation>
    </message>
    <message>
        <source>How many seconds to skip forward on a fast forward.</source>
        <translation>Establece el número de segundos a saltar adelante en el avance rápido.</translation>
    </message>
    <message>
        <source>Rewind amount (in seconds)</source>
        <translation>Atrás (en segundos)</translation>
    </message>
    <message>
        <source>How many seconds to skip backward on a rewind.</source>
        <translation>EStablece cuántos segundos se saltra atrás al retroceder.</translation>
    </message>
    <message>
        <source>Seek to exact frame</source>
        <translation>Buscar un fotograma exacto</translation>
    </message>
    <message>
        <source>If enabled, seeking is frame exact, but slower.</source>
        <translation>Si esta activo, los fotogramas se buscan completos, pero es más lento.</translation>
    </message>
    <message>
        <source>Commercial Skip Method</source>
        <translation>Método de salto de anuncios</translation>
    </message>
    <message>
        <source>Blank Frame Detection (default)</source>
        <translation>Fotogramas en blanco (por defecto)</translation>
    </message>
    <message>
        <source>Blank Frame + Scene Change Detection</source>
        <translation>Fotogramas en blanco + Cambio de escena</translation>
    </message>
    <message>
        <source>Scene Change Detection</source>
        <translation>Cambio de escena</translation>
    </message>
    <message>
        <source>This determines the method used by MythTV to detect when commercials start and end.  You must have automatic commercial turned on to use anything other than &apos;Blank Frame&apos;.</source>
        <translation>ESto determina el método empleado por MythTV para detectar los anuncios. Tiene que tener activa la detección automática de anuncios para usar cualquier otro método distinto a &apos;Fotograma en blanco&apos;.</translation>
    </message>
    <message>
        <source>Automatically Skip Commercials</source>
        <translation>Salto automático de anuncios</translation>
    </message>
    <message>
        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program.</source>
        <translation type="obsolete">Saltarse automáticamente los anuncios cuando fueron detectados por el proceso automático de detección o el programa mythcommflag.</translation>
    </message>
    <message>
        <source>Automatically Flag Commercials</source>
        <translation>Marcar automáticamente los anuncios</translation>
    </message>
    <message>
        <source>Automatically flag commercials after a recording completes.</source>
        <translation>Marcar automáticamente los anunacios después de finalizar una grabación.</translation>
    </message>
    <message>
        <source>Strict Commercial Detection</source>
        <translation>Detección de anuncios estricta</translation>
    </message>
    <message>
        <source>Turn on stricter Commercial Detection code.  If some commercials are not being detected, try turning this setting OFF.</source>
        <translation>Activar la detección de anuncios estricta. Si algunos anuncios no se detectan, pruebe desactivando esta opción.</translation>
    </message>
    <message>
        <source>Auto Expire Free Disk Space Threshold (in Gigabytes)</source>
        <translation>Espacio libre para activar la autoexpiración (en Gigabytes)</translation>
    </message>
    <message>
        <source>Trigger AutoExpire when free space in Gigabytes goes below this value.  Turn OFF AutoExpire by setting to 0.</source>
        <translation>Activa la autoexpiración cuando el espacio libre es inferior a este valor. Desactívelo indicando un valor 0.</translation>
    </message>
    <message>
        <source>Auto Expire Frequency (in minutes)</source>
        <translation>Frecuencia de la autoexpiración (en minutos)</translation>
    </message>
    <message>
        <source>Number of minutes the AutoExpire process will wait between each time that it checks for free disk space.</source>
        <translation>Intervalo en minutos para que el proceso que comprueba la autoexpiración haga la comprobación de espacio libre.</translation>
    </message>
    <message>
        <source>Auto Expire Method</source>
        <translation>Método de autoexpiración</translation>
    </message>
    <message>
        <source>Oldest Show First</source>
        <translation>El más antiguo primero</translation>
    </message>
    <message>
        <source>Method used to determine which recorded shows to AutoExpire first.</source>
        <translation>Método empleado para determinar la primera grabación a borrar.</translation>
    </message>
    <message>
        <source>Auto-Expire Default</source>
        <translation>Autoexpiración por defecto</translation>
    </message>
    <message>
        <source>Turn Auto-Expire ON by default when creating new scheduled recordings.  Existing scheduled recordings will keep their current value.</source>
        <translation>Pone por defecto la autoexpiración activa en las nuevas grabaciones. Las grabaciones ya programadas mantienen su valor actual.</translation>
    </message>
    <message>
        <source>New Recording Free Disk Space Threshold (in Megabytes)</source>
        <translation>ESpacio libre para nuevas grabaciones (en Megabytes)</translation>
    </message>
    <message>
        <source>MythTV will stop scheduling new recordings on a backend when its free disk space falls below this value.</source>
        <translation>MythTV detendrá nuevas grabaciones cuando el espacio libre del sistema sea inferior a este valor.</translation>
    </message>
    <message>
        <source>Time to record before start of show (in seconds)</source>
        <translation>Tiempo a grabar antes de empezar el programa (en segundos)</translation>
    </message>
    <message>
        <source>Time to record past end of show (in seconds)</source>
        <translation>Tiempo a grabar al finalizar el programa (en segundos)</translation>
    </message>
    <message>
        <source>List Newest Recording First</source>
        <translation>La grabación más reciente primero</translation>
    </message>
    <message>
        <source>If checked (default) the most recent recording will be listed first in the &apos;Watch Recordings&apos; screen. If unchecked the oldest recording will be listed first.</source>
        <translation>Si está activo (por defecto) la grabación más reciente se lista primero en la pantalla de &apos;Ver grabaciones&apos;. Si se desactiva, se ordena con la más antigua primero.</translation>
    </message>
    <message>
        <source>Sticky keys</source>
        <translation>Teclas activas</translation>
    </message>
    <message>
        <source>If this is set, fast forward and rewind continue after the key is released.  Pressing the key again increases the fast forward or rewind speed.  The alternate fast forward and rewind keys always behave in this way.</source>
        <translation>Si está activo, el avance/retroceso prosigue después de pulsar la tecla. Pulsándola de nuevo incrementa la velocidad. Las teclas alternativas de avance y retroceso siempre se comportan de esta forma.</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Inglés</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="obsolete">Italiano</translation>
    </message>
    <message>
        <source>Catalan</source>
        <translation type="obsolete">Catalàn</translation>
    </message>
    <message>
        <source>Spanish</source>
        <translation type="obsolete">Español</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="obsolete">Holandés</translation>
    </message>
    <message>
        <source>French</source>
        <translation type="obsolete">Francés</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="obsolete">Alemán</translation>
    </message>
    <message>
        <source>Danish</source>
        <translation type="obsolete">Danés</translation>
    </message>
    <message>
        <source>Swedish</source>
        <translation type="obsolete">Sueco</translation>
    </message>
    <message>
        <source>Portuguese</source>
        <translation type="obsolete">Portugués</translation>
    </message>
    <message>
        <source>Your preferred language.</source>
        <translation>Su idioma preferido.</translation>
    </message>
    <message>
        <source>Setup Pin Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This PIN is used to control access to the setup menues. If you want to use this feature, then setting the value to all numbers will make your life much easier.  Set it to blank to disable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Require Setup PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Setup PIN without first entering the current PIN.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reposition after fast forward/rewind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When exiting sticky keys fast forward/rewind mode, reposition before resuming normal playback.  This is to compensate for the reaction time between seeing where to resume playback and actually exiting fast forward/rewind mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of seconds for OSD information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How long the program information remains on the On Screen Display after a channel change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OSD theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OSD font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Closed Caption font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel ordering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel number (numeric)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel number (alpha)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>database order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>channel name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical over/underscan percentage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this if the image does not fill your screen vertically.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal over/underscan percentage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this if the image does not fill your screen horizontally.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan displacement (X)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this to move the image horizontally.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scan displacement (Y)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust this to move the image vertically.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jitter reduction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, frame timing will be adjusted for smoother motion.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Experimental A/V Sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, more experimental code will be in charge of video output. Use at your own risk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default setting for Closed Captioning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, captions will be on by default when playing back recordings or watching live TV.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always use Browse mode when changing channels in LiveTV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, Browse mode will automatically be activated whenever you use Channel UP/DOWN when watching Live TV.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aggressive Soundcard Buffering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set, MythTV will pretend to have a smaller soundcard buffer than is really present.  This may speed up seeking, but can also cause playback problems.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Saved Position on playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically clear saved position on a recording when the recording is played back.  If UNset, you can mark the beginning with rewind then save position.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Clear Saved Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, during playback the select key (Enter or Space) will alternate between &quot;Position Saved&quot; and &quot;Position Cleared&quot;. If UNset, select will save the current position for each keypress.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action on playback exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Just exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save position and exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always prompt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set to prompt, a menu will be displayed when you exit playback mode.  The options available will allow you to save your position, delete the recording, or continue watching.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prompt at end of recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, a menu will be displayed allowing you to delete the recording when it has finished playing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate thumbnail preview images for recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, a static image of the recording will be displayed on the &quot;Watch a Recording&quot; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display live preview of recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, a preview of the recording will play in a small window on the &quot;Watch a Recording&quot; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Transparent Boxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the Watch Recording and Delete Recording screens will use transparency. Unset this option if selecting the recordings is slow.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Popup Background Shading Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill is the quickest method, but it doesn&apos;t look good up close. Image looks good from up close, but is somewhat slow. And of course no shading will be the fastest.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always use Advanced Recording Options screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always use the Advanced Recording Options screen when editing a scheduled recording.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System shutdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No exit key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Control-ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta-ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt-ESC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythTV is designed to run continuously. If you wish, you may use the ESC key or the ESC key + a modifier to exit MythTV. Do not choose a key combination that will be intercepted by your window manager.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Halt command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you have configured an exit key on the System Shutdown menu, you will be given the opportunity to exit MythTV or halt the system completely. Another possibility for this field is poweroff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xinerama screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If using Xinerama, run only on the specified screen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The width of the GUI.  Do not make the GUI wider than your actual screen resolution.  Set to 0 to automatically scale to fullscreen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The height of the GUI.  Do not make the GUI taller than your actual screen resolution.  Set to 0 to automatically scale to fullscreen.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI X offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The horizontal offset the GUI will be displayed at.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GUI Y offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The vertical offset the GUI will be displayed at.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run the frontend in a window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggles between borderless operation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a random theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a random theme each time MythTV is started.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ddd MMM d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ddd MMMM d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MMM d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MM/dd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MM.dd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ddd d MMM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dd.MM.yyyy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your preferred date format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Short Date format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>M/d</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d/M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dd/MM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d.M.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dd.MM.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your preferred short date format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>h:mm AP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>h:mm ap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hh:mm AP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hh:mm ap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>h:mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hh:mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your preferred time format.  Choose a format with &quot;AP&quot; in it for an AM/PM display, otherwise your time display will be 24-hour or &quot;military&quot; time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Problem reading theme preview image </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display channel names instead of numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;Big&quot; font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;Medium&quot; font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;Small&quot; font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program Guide Selection Placement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If unchecked, the program guide&apos;s selector will stay in the middle of the guide at all times.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guide Shading Method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colorized (alpha)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colorized (shaded)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Embossed (shaded)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Embossed (solid)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rounded (shaded)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rounded (solid)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display the channel icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels to Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Blocks (30 mins) to Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Guide starts at channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The program guide starts on this channel if it is run from outside of LiveTV mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What to call &apos;unknown&apos; programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What category to give &apos;unknown&apos; programs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Xbox Hardware</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This enables support for Xbox Specific hardware. Requires a frontend restart for changes to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Xbox Linux Distribution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is used to determine the name of the blink binary led will be used on GentooX, blink otherwise.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default LED mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orange</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This sets the LED mode when there is nothing else to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording LED mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This sets the LED mode when a backend is recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording Check Frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This specifies how often in seconds to check if a recording is in progress and update the Xbox LED.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General playback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seeking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commercial Detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overscan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On-screen display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global Auto Expire Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program Guide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screen settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Localization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Create new profile group)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Profile name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MP3 Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The higher the slider number, the lower the quality of the audio.  Better quality audio (lower numbers) requires more CPU.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the audio sampling rate for your DSP. Ensure that you choose a sampling rate appropriate for your device.  btaudio may only allow 32000.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the audio type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the audio bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume (%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume of the recording </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RTjpeg Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Higher is better quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luma filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower is better.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chroma filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bitrate in kilobits/second.  2200Kbps is approximately 1 Gigabyte per hour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale bitrate for frame size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MPEG4 bitrate will be used for 640x480.  If other resolutions are used, the bitrate will be scaled appropriately.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modifying the default may have severe consequences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max quality difference between frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable high-quality encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MPEG4 encoder will use &apos;high-quality&apos; encoding options.  This requires much more processing, but can result in better video.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable 4MV encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MPEG4 encoder will use &apos;4MV&apos; motion-vector encoding.  This requires much more processing, but can result in better video. It is highly recommended that the HQ option is enabled if 4MV is enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Bitrate in kilobits/second.  2200Kbps is approximately 1 Gigabyte per hour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the type of stream generated by your PVR.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aspect Ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Square</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the aspect ratio of stream generated by your PVR.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal Decimation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Decimation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RTjpeg Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG-4 Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardware MJPEG Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG-2 Hardware Encoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically transcode after recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mixer Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Fast Forwarding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If enabled, then immediately after rewinding, only skip forward the same amount as skipping backwards.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Xv picture controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, Xv picture controls (brightness, contrast, etc.) are used during playback. These are independent of the v4l controls used for recording. The Xv controls may not work properly on some systems.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the PVR-350&apos;s TV out / MPEG decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythTV can use the PVR-350&apos;s TV out and MPEG decoder for high quality playback.  This requires that the ivtv-fb kernel module is also loaded and set up properly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video device for the PVR-350 MPEG decoder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PVR-350 Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced Filter configuration, format:
[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>big</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>default: TV, small: monitor, big:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change channels immediately without select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General playback (part 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commercial: %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pre-Roll Minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Post-Roll Minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify, but do not skip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Skip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UDP Notify Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skip blank frames after commercials</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Recording on cardid: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not Recording: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual Override</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previously Recorded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Currently Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Showing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too Many Recordings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Record List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower Rec Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual Conflict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Conflict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reason Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daily Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekly Recording</source>
        <translation type="unfinished">Grabación semanal</translation>
    </message>
    <message>
        <source>Conflicting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Will Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Won&apos;t Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t record it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never record this episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record it anyway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember this choice and use it automatically in the future</source>
        <translation type="unfinished">Recordar esta opción y usarla automáticamente en el futuro</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AC3 to SPDIF passthrough</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PIP Video Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location of PIP Video window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reverse direction in fast forward/rewind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Recording Priorities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use program recording priorities to resolve conflicts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording Priorities First.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Single Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekslot Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weekslot Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeslot Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timeslot Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel Recordings will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Recordings Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Recording types will receive this additional recording priority value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Recording Priorities Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes, Exit and Shutdown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RankPrograms</name>
    <message>
        <source>Recording just this showing</source>
        <translation type="obsolete">Graba el programa solamente esta vez</translation>
    </message>
    <message>
        <source>Recording every week</source>
        <translation type="obsolete">Grabar cada semana</translation>
    </message>
    <message>
        <source>Recording when shown in this timeslot</source>
        <translation type="obsolete">Grabarlo cuando aparezca a esta hora</translation>
    </message>
    <message>
        <source>Recording when shown on this channel</source>
        <translation type="obsolete">Grabarlo cuando aparezca en este canal</translation>
    </message>
    <message>
        <source>Recording all showings</source>
        <translation type="obsolete">Grabarlo siempre que aparezca</translation>
    </message>
    <message>
        <source>Not recording this showing</source>
        <translation type="obsolete">No grabar este programa</translation>
    </message>
    <message>
        <source>Error!</source>
        <translation type="obsolete">¡ Error !</translation>
    </message>
</context>
<context>
    <name>ScheduledRecording</name>
    <message>
        <source>Episode:</source>
        <translation type="obsolete">Episodio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="obsolete">Descripción:</translation>
    </message>
    <message>
        <source>See a list of all up-coming episodes/playtimes.</source>
        <translation>Ver cuándo se emiten los próximos episodios.</translation>
    </message>
</context>
<context>
    <name>Scheduler</name>
    <message>
        <source>the maximum number of episodes have already been recorded.</source>
        <translation type="obsolete">se alcanzó el número máximo de episodios a grabar.</translation>
    </message>
</context>
<context>
    <name>SetRecTimeDialog</name>
    <message>
        <source>Change recording time:</source>
        <translation type="obsolete">Cambiar el tiempo de grabación:</translation>
    </message>
    <message>
        <source>Episode:</source>
        <translation type="obsolete">Episodio:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="obsolete">Descripción:</translation>
    </message>
    <message>
        <source>Start Time: </source>
        <translation type="obsolete">Fecha de Inicio:</translation>
    </message>
    <message>
        <source>End Time: </source>
        <translation type="obsolete">Fecha de Fin:</translation>
    </message>
</context>
<context>
    <name>TV</name>
    <message>
        <source>MythTV is already using all available inputs for recording.  If you want to watch an in-progress recording, select one from the playback menu.  If you want to watch live TV, cancel one of the in-progress recordings from the delete menu.</source>
        <translation>MythTV esta ya usando todos los sintonizadores disponibles. Si quiere ver la grabación en curso, seleccionela desde el menú de reproducción. Si quiere ver la TV, cancele la grabación en curso desde el menú de borrar grabaciones.</translation>
    </message>
    <message>
        <source>Cancel and go back to the TV menu</source>
        <translation>Cancelar y volver al menú de TV</translation>
    </message>
    <message>
        <source>Record and watch while it records</source>
        <translation>Grabar y ver mientras se graba</translation>
    </message>
    <message>
        <source>Let it record and go back to the Main Menu</source>
        <translation>Dejar grabar i volver al menú principal</translation>
    </message>
    <message>
        <source>Don&apos;t let it record, I want to watch TV</source>
        <translation>No grabar, quiero ver la TV</translation>
    </message>
    <message>
        <source>You are exiting this recording</source>
        <translation>Está saliendo de la grabación</translation>
    </message>
    <message>
        <source>Save this position and go to the menu</source>
        <translation>Guardar esta posición y volver al menú</translation>
    </message>
    <message>
        <source>Do not save, just exit to the menu</source>
        <translation>No guardar, salir al menú</translation>
    </message>
    <message>
        <source>Keep watching</source>
        <translation>Seguir viendo</translation>
    </message>
    <message>
        <source>Delete this recording</source>
        <translation>Borrar esta grabación</translation>
    </message>
    <message>
        <source>Brightness %1 %</source>
        <translation>Brillo %1 %</translation>
    </message>
    <message>
        <source>Adjust Picture</source>
        <translation>Ajustar Imagen</translation>
    </message>
    <message>
        <source>Contrast %1 %</source>
        <translation>Contraste %1 %</translation>
    </message>
    <message>
        <source>Colour %1 %</source>
        <translation>Color %1 %</translation>
    </message>
    <message>
        <source>Volume %1 %</source>
        <translation>Volumen %1 %</translation>
    </message>
    <message>
        <source>Adjust Volume</source>
        <translation>Ajustar Volumen</translation>
    </message>
    <message>
        <source>Mute On</source>
        <translation>Sin Sonido</translation>
    </message>
    <message>
        <source>Mute Off</source>
        <translation>Con Sonido</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind  --  %.2f%% full</source>
        <translation type="obsolete">%02d:%02d:%02d atrás -- %.2f%% lleno</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d behind</source>
        <translation type="obsolete">%02d:%02d:%02d atrás</translation>
    </message>
    <message>
        <source>%02d:%02d behind  --  %.2f%% full</source>
        <translation type="obsolete">%02d:%02d atrás -- %.2f%% lleno</translation>
    </message>
    <message>
        <source>%02d:%02d behind</source>
        <translation type="obsolete">%02d:%02d atrás</translation>
    </message>
    <message>
        <source>%02d:%02d:%02d of %02d:%02d:%02d</source>
        <translation type="obsolete">%02d:%02d:%02d de %02d:%02d:%02d</translation>
    </message>
    <message>
        <source>%02d:%02d of %02d:%02d</source>
        <translation type="obsolete">%02d:%02d de %02d:%02d</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <source>Forward </source>
        <translation>Adelante </translation>
    </message>
    <message>
        <source>Rewind </source>
        <translation>Atrás </translation>
    </message>
    <message>
        <source>Jump Ahead</source>
        <translation>Salto Adelante</translation>
    </message>
    <message>
        <source>Jump Back</source>
        <translation>Salto Atràs</translation>
    </message>
    <message>
        <source>SKIP</source>
        <translation type="obsolete">SALTO</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <source>Hue %1 %</source>
        <translation>Tono %1 %</translation>
    </message>
    <message>
        <source>Stopping Transcode</source>
        <translation>Parar Trascodificación</translation>
    </message>
    <message>
        <source>Transcoding</source>
        <translation>Trascodificación</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avance</translation>
    </message>
    <message>
        <source>Skip Ahead</source>
        <translation>Salto adelante</translation>
    </message>
    <message>
        <source>Rewind</source>
        <translation>Atràs</translation>
    </message>
    <message>
        <source>Skip Back</source>
        <translation>Salto atrás</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Speed 5X</source>
        <translation>Velocidad 5X</translation>
    </message>
    <message>
        <source>Speed 3X</source>
        <translation>Velocidad 3X</translation>
    </message>
    <message>
        <source>Speed 2X</source>
        <translation></translation>
    </message>
    <message>
        <source>Speed 1/3X</source>
        <translation>Velocidad 1/3X</translation>
    </message>
    <message>
        <source>Speed 1/8X</source>
        <translation>Velocidad 1/8X</translation>
    </message>
    <message>
        <source>Speed 1/16X</source>
        <translation>Velocidad 1/16X</translation>
    </message>
    <message>
        <source>Skip</source>
        <translation>Salta</translation>
    </message>
    <message>
        <source>16:9</source>
        <translation></translation>
    </message>
    <message>
        <source>4:3</source>
        <translation>4:3</translation>
    </message>
    <message>
        <source>This program is currently being edited</source>
        <translation>Este programa se está editando</translation>
    </message>
    <message>
        <source>Continue Editing</source>
        <translation>Continuar editando</translation>
    </message>
    <message>
        <source>Do not edit</source>
        <translation>No editar</translation>
    </message>
    <message>
        <source>4:3 Zoom</source>
        <translation type="unfinished">Zoom 4:3</translation>
    </message>
    <message>
        <source>Brightness (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contrast (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colour (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hue (REC) %1 %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Program Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Commercial Auto-Skip OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Commercial Auto-Skip ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Commercial Auto-Skip to Notify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Auto Expire</source>
        <translation type="unfinished">No autoexpirar</translation>
    </message>
    <message>
        <source>Auto Expire</source>
        <translation type="unfinished">Autoexpirar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Skip OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Skip ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Skip Notify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16:9 Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ViewScheduled</name>
    <message>
        <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
        <translation type="obsolete">La grabación de este programa ha sido desactivada porque estaba en conflicto con otra grabación. ¿Desea volver a activar esta grabación?</translation>
    </message>
    <message>
        <source>Yes, I want to record it.</source>
        <translation type="obsolete">Si, quiero grabarlo.</translation>
    </message>
    <message>
        <source>No, leave it disabled.</source>
        <translation type="obsolete">No, mantener desactivada.</translation>
    </message>
    <message>
        <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
        <translation type="obsolete">Esta grabación fué cancelada porque ya se grabó anteriormente.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
        <translation type="obsolete">Estas grabaciones programadas estan en conflicto entre sí. ¿Cuál quiere mantener?</translation>
    </message>
    <message>
        <source>Remember this choice and use it automatically in the future</source>
        <translation type="obsolete">Recordar esta opción y usarla automáticamente en el futuro</translation>
    </message>
    <message>
        <source>Time Conflict</source>
        <translation>Conflicto en el tiempo</translation>
    </message>
    <message>
        <source>No Conflicts</source>
        <translation>Sin conflictos</translation>
    </message>
    <message>
        <source>Unsuppress recording</source>
        <translation type="obsolete">Desuprimir grabación</translation>
    </message>
    <message>
        <source>Recording this program has been suppressed because: </source>
        <translation type="obsolete">Esta grabación se suspendió por la siguiente causa:</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Important</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
